-- LDAP ASN1 Schema Definitions
-- NetIQ Corporation
-- 1233 West Loop South, Suite 810 
-- Houston, TX 77027 USA

-- CoPyRiGhT=Copyright (c) 2013 NetIQ Corporation and its affiliates. All Rights Reserved.

-- Schema Source:		ldap.sch
-- Description:			Schema definitions needed for NetIQ's LDAP server to function properly
-- %version:			idc_n4u#62.1.11 %
-- %date_modified:		Wed May 25 12:48:30 2011 %

LDAPSchemaExtentions DEFINITIONS ::=
BEGIN

------------------------------------------
-- Legacy Attributes:
------------------------------------------
"LDAP Log Level" ATTRIBUTE ::=
{
	SyntaxID    SYN_INTEGER,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_SIZED_ATTR, DS_SYNC_IMMEDIATE},
	LowerBound  0,
	UpperBound  32768,
	ASN1ObjID   {2 16 840 1 113719 1 1 4 1 1 192}
}

"LDAP UDP Port" ATTRIBUTE ::=
{
	SyntaxID    SYN_INTEGER,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_SIZED_ATTR, DS_SYNC_IMMEDIATE},
	LowerBound  0,
	UpperBound  65535,
	ASN1ObjID   {2 16 840 1 113719 1 27 4 12}
}

"LDAP Log Filename" ATTRIBUTE ::=
{
	SyntaxID    SYN_CI_STRING,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_STRING_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 1 4 1 204}
}

"LDAP Backup Log Filename" ATTRIBUTE ::=
{
	SyntaxID    SYN_CI_STRING,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_STRING_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 1 4 1 205}
}

"LDAP Log Size Limit" ATTRIBUTE ::=
{
	SyntaxID    SYN_INTEGER,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_SIZED_ATTR, DS_SYNC_IMMEDIATE},
	LowerBound  2048,
	UpperBound  4294967295,
	ASN1ObjID   {2 16 840 1 113719 1 1 4 1 206}
}

"LDAP Search Size Limit" ATTRIBUTE ::=
{
	SyntaxID    SYN_INTEGER,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_SIZED_ATTR, DS_SYNC_IMMEDIATE},
	LowerBound  1,
	UpperBound  2147483647,
	ASN1ObjID   {2 16 840 1 113719 1 1 4 1 194}
}

"LDAP Search Time Limit" ATTRIBUTE ::=
{
	SyntaxID    SYN_INTEGER,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_SIZED_ATTR, DS_SYNC_IMMEDIATE},
	LowerBound  1,
	UpperBound  2147483647,
	ASN1ObjID   {2 16 840 1 113719 1 1 4 1 195}
}

"LDAP Suffix" ATTRIBUTE ::=
{
	SyntaxID    SYN_DIST_NAME,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 1 4 1 207}
}

------------------------------------------
-- LDAP Shared Config Attributes:
------------------------------------------
"ldapConfigVersion" ATTRIBUTE ::=
{
	SyntaxID	SYN_INTEGER,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID	{2 16 840 1 113719 1 27 4 70}
}

"LDAP Referral" ATTRIBUTE ::=
{
	SyntaxID	SYN_CI_STRING,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_STRING_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID	{2 16 840 1 113719 1 27 4 14}
}

-- The traditional default referral behavior was that it would be returned during 
-- name resolution if an entry is not local and a referral is not available, 
-- or if an entry is not found. It was also returned while searching, and a 
-- subordinate referral was not available. 
-- As of 8.7.0, this attribute will control the behavior of the default referral.
-- This is a bitmask of the following values (values may be OR'd together)
--	0 indicates that the default referral will be used as the DSA superior reference.
--	1 indicates that the default referral will be returned during name resolution, 
--	  when the server is set to refer, and when an eDirectory referral is found, 
--	  but no LDAP service is running at that address.
--	2 indicates that the default referral is returned during name resolution, when 
--	  configured to return referrals, and an entry is not found in an area that the 
--	  DSA is authoritative for, the default referral will be returned.
--	4 indicates that the default referral is returned during a search (while processing
--	  entries), if the server is configured to send referrals, and if an eDirectory 
--	  referral is found but no LDAP service is running at that address.
--	Future values may be defined to take on other meanings.
-- This setting exists on the LDAP Group and LDAP Server object, and the LDAP Server 
-- setting will override the LDAP Group setting (even if there is not a default referral 
-- on the LDAP Server).
"ldapDefaultReferralBehavior" ATTRIBUTE ::=
{
	SyntaxID	SYN_INTEGER,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID	{2 16 840 1 113719 1 27 4 73}
}

"LDAP:searchReferralUsage" ATTRIBUTE ::=
{
	SyntaxID	SYN_INTEGER,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID	{2 16 840 1 113719 1 27 4 23}
}

"LDAP:otherReferralUsage" ATTRIBUTE ::=
{
	SyntaxID	SYN_INTEGER,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID	{2 16 840 1 113719 1 27 4 24}
}

------------------------------------------
-- LDAP Server Attributes:
------------------------------------------
"LDAP Host Server" ATTRIBUTE ::=
{
	SyntaxID	SYN_DIST_NAME,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID	{2 16 840 1 113719 1 27 4 1}
}

"LDAP Group" ATTRIBUTE ::=
{
	SyntaxID	SYN_DIST_NAME,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID	{2 16 840 1 113719 1 27 4 2}
}

"LDAP Screen Level" ATTRIBUTE ::=
{
	SyntaxID	SYN_INTEGER,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_SIZED_ATTR, DS_SYNC_IMMEDIATE},
	LowerBound	0,
	UpperBound	32768,
	ASN1ObjID	{2 16 840 1 113719 1 27 4 3}
}

"searchSizeLimit" ATTRIBUTE ::=
{
	SyntaxID	SYN_INTEGER,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_SIZED_ATTR, DS_SYNC_IMMEDIATE},
	LowerBound	0,
	UpperBound	2147483647,
	ASN1ObjID	{2 16 840 1 113719 1 27 4 4}
}

"searchTimeLimit" ATTRIBUTE ::=
{
	SyntaxID	SYN_INTEGER,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_SIZED_ATTR, DS_SYNC_IMMEDIATE},
	LowerBound	0,
	UpperBound	2147483647,
	ASN1ObjID	{2 16 840 1 113719 1 27 4 5}
}

"LDAP Server Bind Limit" ATTRIBUTE ::=
{
	SyntaxID	SYN_INTEGER,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_SIZED_ATTR, DS_SYNC_IMMEDIATE},
	LowerBound	0,
	UpperBound	4294967295,
	ASN1ObjID	{2 16 840 1 113719 1 27 4 6}
}

"LDAP Server Idle Timeout" ATTRIBUTE ::=
{
	SyntaxID	SYN_INTEGER,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_SIZED_ATTR, DS_SYNC_IMMEDIATE},
	LowerBound	0,
	UpperBound	4294967295,
	ASN1ObjID	{2 16 840 1 113719 1 27 4 7}
}

"LDAP Enable TCP" ATTRIBUTE ::=
{
	SyntaxID	SYN_BOOLEAN,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID	{2 16 840 1 113719 1 27 4 8}
}

"LDAP Enable SSL" ATTRIBUTE ::=
{
	SyntaxID	SYN_BOOLEAN,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID	{2 16 840 1 113719 1 27 4 10}
}

"LDAP TCP Port" ATTRIBUTE ::=
{
	SyntaxID	SYN_INTEGER,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_SIZED_ATTR, DS_SYNC_IMMEDIATE},
	LowerBound	0,
	UpperBound	65535,
	ASN1ObjID	{2 16 840 1 113719 1 27 4 11}
}

"LDAP SSL Port" ATTRIBUTE ::=
{
	SyntaxID	SYN_INTEGER,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_SIZED_ATTR, DS_SYNC_IMMEDIATE},
	LowerBound	0,
	UpperBound	65535,
	ASN1ObjID	{2 16 840 1 113719 1 27 4 13}
}

"filteredReplicaUsage" ATTRIBUTE ::=
{
	SyntaxID				SYN_INTEGER,
	Flags						 {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID	{2 16 840 1 113719 1 27 4 21}
}

"LDAP:keyMaterialName" ATTRIBUTE ::=
{
	SyntaxID	SYN_CI_STRING,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_STRING_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID	{2 16 840 1 113719 1 27 4 22}
}

"extensionInfo" ATTRIBUTE ::=
{
	SyntaxID	SYN_OCTET_STRING,
	Flags		{DS_SYNC_IMMEDIATE, DS_PUBLIC_READ},
	ASN1ObjID	{2 16 840 1 113719 1 27 4 42}
}

"nonStdClientSchemaCompatMode" ATTRIBUTE ::=
{
	SyntaxID	SYN_BOOLEAN,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID	{2 16 840 1 113719 1 27 4 45}
}

"sslEnableMutualAuthentication" ATTRIBUTE ::=
{
	SyntaxID	SYN_BOOLEAN,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID	{2 16 840 1 113719 1 27 4 46}
}

"ldapEnablePSearch" ATTRIBUTE ::=
{
	SyntaxID	SYN_BOOLEAN,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID	{2 16 840 1 113719 1 27 4 62}
}

"ldapMaximumPSearchOperations" ATTRIBUTE ::=
{
	SyntaxID	SYN_INTEGER,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID	{2 16 840 1 113719 1 27 4 63}
}

"ldapIgnorePSearchLimitsForEvents" ATTRIBUTE ::=
{
	SyntaxID	SYN_BOOLEAN,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID	{2 16 840 1 113719 1 27 4 64}
}

"ldapTLSTrustedRootContainer" ATTRIBUTE ::=
{
	SyntaxID	SYN_DIST_NAME,
	Flags		{DS_SYNC_IMMEDIATE},
	ASN1ObjID	{2 16 840 1 113719 1 27 4 65}
}

"ldapEnableMonitorEvents" ATTRIBUTE ::=
{
	SyntaxID	SYN_BOOLEAN,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID	{2 16 840 1 113719 1 27 4 66}
}

"ldapMaximumMonitorEventsLoad" ATTRIBUTE ::=
{
	SyntaxID	SYN_INTEGER,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID	{2 16 840 1 113719 1 27 4 67}
}

"ldapTLSRequired" ATTRIBUTE ::=
{
	SyntaxID	SYN_BOOLEAN,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID	{2 16 840 1 113719 1 27 4 68}
}

"ldapTLSVerifyClientCertificate" ATTRIBUTE ::=
{
	SyntaxID	SYN_INTEGER,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID	{2 16 840 1 113719 1 27 4 69}
}

"ldapDerefAlias" ATTRIBUTE ::=
{
	SyntaxID	SYN_BOOLEAN,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID	{2 16 840 1 113719 1 27 4 71}
}

"ldapNonStdAllUserAttrsMode" ATTRIBUTE ::=
{
	SyntaxID	SYN_BOOLEAN,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID	{2 16 840 1 113719 1 27 4 72}
}

"ldapBindRestrictions" ATTRIBUTE ::=
{
	SyntaxID	SYN_INTEGER,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID	{2 16 840 1 113719 1 27 4 75}
}

"ldapInterfaces" ATTRIBUTE ::=
{
	SyntaxID	SYN_CI_STRING,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113719 1 27 4 79}
}

"ldapChainSecureRequired" ATTRIBUTE ::=
{
	SyntaxID	SYN_BOOLEAN,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID	{2 16 840 1 113719 1 27 4 80}
}

"ldapStdCompliance" ATTRIBUTE ::=
{
 SyntaxID SYN_INTEGER,
 Flags		{DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
 ASN1ObjID	{2 16 840 1 113719 1 27 4 82}
}

"ldapDerefAliasOnAuth" ATTRIBUTE ::=
{
	SyntaxID	SYN_BOOLEAN,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID	{2 16 840 1 113719 1 27 4 83}
}

"ldapGeneralizedTime" ATTRIBUTE ::=
{
	SyntaxID        SYN_BOOLEAN,
	Flags           {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID       {2 16 840 1 113719 1 27 4 84}
}

"ldapPermissiveModify" ATTRIBUTE ::=
{
	SyntaxID        SYN_BOOLEAN,
	Flags           {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID       {2 16 840 1 113719 1 27 4 85}
}

"ldapSSLConfig"	ATTRIBUTE ::=
{
	SyntaxID	SYN_STREAM,
	Flags		{DS_SINGLE_VALUED_ATTR},
	ASN1ObjID	{2 16 840 1 113719 1 27 4 86}
}

------------------------------------------
-- LDAP Group Attributes:
------------------------------------------

"LDAP Server List" ATTRIBUTE ::=
{
	SyntaxID	SYN_DIST_NAME,
	Flags		{DS_SYNC_IMMEDIATE},
	ASN1ObjID	{2 16 840 1 113719 1 27 4 15}
}

"LDAP Attribute Map v11" ATTRIBUTE ::=
{
	SyntaxID	SYN_OCTET_STRING,
	Flags		{DS_SYNC_IMMEDIATE, DS_SINGLE_VALUED_ATTR},
	ASN1ObjID	{2 16 840 1 113719 1 27 4 16}
}

"LDAP Class Map v11" ATTRIBUTE ::=
{
	SyntaxID	SYN_OCTET_STRING,
	Flags		{DS_SYNC_IMMEDIATE, DS_SINGLE_VALUED_ATTR},
	ASN1ObjID	{2 16 840 1 113719 1 27 4 17}
}

"LDAP Allow Clear Text Password" ATTRIBUTE ::=
{
	SyntaxID	SYN_BOOLEAN,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID	{2 16 840 1 113719 1 27 4 18}
}

"LDAP Anonymous Identity" ATTRIBUTE ::=
{
	SyntaxID	SYN_DIST_NAME,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID	{2 16 840 1 113719 1 27 4 19}
}

"ldapAttributeList" ATTRIBUTE ::=
{
	SyntaxID	SYN_CI_LIST,
	Flags		{DS_SYNC_IMMEDIATE},
	ASN1ObjID	{2 16 840 1 113719 1 27 4 52}
}

"ldapClassList" ATTRIBUTE ::=
{
	SyntaxID	SYN_CI_LIST,
	Flags		{DS_SYNC_IMMEDIATE},
	ASN1ObjID	{2 16 840 1 113719 1 27 4 53}
}

"transitionGroupDN" ATTRIBUTE ::=
{
	SyntaxID	SYN_DIST_NAME,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID	{2 16 840 1 113719 1 27 4 56}
}

"ldapTransitionBackLink" ATTRIBUTE ::=
{
	SyntaxID	SYN_DIST_NAME,
	Flags		{DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID	{2 16 840 1 113719 1 27 4 74}
}

"ldapLBURPNumWriterThreads" ATTRIBUTE ::=
{
	SyntaxID        SYN_INTEGER,
	Flags           {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	LowerBound  	1,
	UpperBound 		8,
	ASN1ObjID       {2 16 840 1 113719 1 27 4 78}
}

------------------------------------------
-- NCP Server Attributes:
------------------------------------------
"LDAP Server" ATTRIBUTE ::=
{
	SyntaxID	SYN_DIST_NAME,
	Flags		{DS_SYNC_IMMEDIATE},
	ASN1ObjID	{2 16 840 1 113719 1 27 4 20}
}


------------------------------------------
-- LDAP Server Object Class - original definition
-- None of these attributes can be removed, but they can be
-- changed to legacy status.  Only if an entire tree is upgraded
-- or installed new with a version later than 8.7 can the 
-- legacy attributes be removed
------------------------------------------
"LDAP Server" OBJECT-CLASS ::=
{
	Operation	ADD,
	SubClassOf	{"TOP"},
	Flags		{DS_EFFECTIVE_CLASS},
	ContainedBy	{"Country", "Locality",	"Organizational Unit", "Organization"},
	NamedBy		{"CN"},
	MustContain	{"CN"},
	-- Order is not significant.
	MayContain	{"LDAP Host Server",		"LDAP Group",
		   		"LDAP Screen Level",		"LDAP Server Bind Limit",
		   		"LDAP Server Idle Timeout"},
	ASN1ObjID	{2 16 840 1 113719 1 27 6 1}
}

------------------------------------------
-- LDAP Server Object Class - additional modifications
-- Legacy attributes still present only because older
-- versions of the LDAP Server code still use them:
-- "LDAP UDP Port",	"LDAP Search Size Limit", "LDAP Search Time Limit",
-- "LDAP Log Level", "LDAP Log Filename", "LDAP Backup Log Filename",
-- "LDAP Log Size Limit"
--
-- All modifications are now done in a single modify operation
-- The complete definition is repeated here, with all desired 
-- changes done at once. 
------------------------------------------
"LDAP Server" OBJECT-CLASS ::=
{
	Operation	MODIFY,
	SubClassOf	{"TOP"},
	Flags		{DS_EFFECTIVE_CLASS},
	ContainedBy	{"Country", "Locality",	"Organizational Unit", "Organization", "domain"},
	NamedBy		{"CN"},
	MustContain	{"CN"},
	-- Order is not significant.
	MayContain	{"LDAP Host Server",  				"LDAP Group",
				"LDAP Screen Level", 		 		"LDAP Server Bind Limit",
				"LDAP Server Idle Timeout",			"LDAP UDP Port",
				"LDAP Search Size Limit",			"LDAP Search Time Limit",
				"LDAP Log Level",					"LDAP Log Filename",
				"LDAP Backup Log Filename",			"LDAP Log Size Limit",
				"Version",							"searchSizeLimit",
				"searchTimeLimit",					"LDAP Enable TCP",
				"LDAP TCP Port",					"LDAP Enable SSL",
				"LDAP SSL Port",					"LDAP:keyMaterialName",
				"filteredReplicaUsage",				"extensionInfo",
				"nonStdClientSchemaCompatMode",		"sslEnableMutualAuthentication",
				"ldapEnablePSearch",				"ldapMaximumPSearchOperations",
				"ldapIgnorePSearchLimitsForEvents",	"ldapTLSTrustedRootContainer",
				"ldapEnableMonitorEvents",			"ldapMaximumMonitorEventsLoad",
				"ldapTLSRequired",					"ldapTLSVerifyClientCertificate",
				"ldapConfigVersion",				"ldapDerefAlias",
				"ldapNonStdAllUserAttrsMode",		"ldapBindRestrictions",
				"ldapDefaultReferralBehavior",		"LDAP Referral",
				"LDAP:searchReferralUsage",			"LDAP:otherReferralUsage",
				"ldapLBURPNumWriterThreads",        "ldapInterfaces",
				"ldapChainSecureRequired",			"ldapStdCompliance",
				"ldapDerefAliasOnAuth",		"ldapGeneralizedTime",
				"ldapPermissiveModify", "ldapSSLConfig"
	},
	ASN1ObjID	{2 16 840 1 113719 1 27 6 1}
}

------------------------------------------
-- LDAP Group Object Class - original definition
-- None of these attributes can be removed, but they can be
-- changed to legacy status.  Only if an entire tree is upgraded
-- or installed new with a version later than 8.7 can the 
-- legacy attributes be removed

------------------------------------------
"LDAP Group" OBJECT-CLASS ::=
{
	Operation	ADD,
	SubClassOf	{"TOP"},
	Flags		{DS_EFFECTIVE_CLASS},
	ContainedBy	{"Country", "Locality",	"Organizational Unit", "Organization"},
	NamedBy		{"CN"},
	MustContain	{"CN"},
	MayContain	{"LDAP Referral",					"LDAP Server List",
				"LDAP Allow Clear Text Password",	"LDAP Anonymous Identity"},
	ASN1ObjID	{2 16 840 1 113719 1 27 6 2}
}

------------------------------------------
-- LDAP Group Object Class - additional modifications
-- Legacy attributes still present only because older
-- versions of the LDAP Server code still use them:
-- "LDAP Suffix", "LDAP Attribute Map v11",	"LDAP Class Map v11",
-- "LDAP:searchReferralUsage", "LDAP:otherReferralUsage" 
--
-- All modifications are now done in a single modify operation
-- The complete definition is repeated here, with all desired 
-- changes done at once. 
------------------------------------------
"LDAP Group" OBJECT-CLASS ::=
{
	Operation	MODIFY,
	SubClassOf	{"TOP"},
	Flags		{DS_EFFECTIVE_CLASS},
	ContainedBy	{"Country", "Locality",	"Organizational Unit", "Organization", "domain"},
	NamedBy		{"CN"},
	MustContain	{"CN"},
	MayContain	{"LDAP Referral",					"LDAP Server List",
				"LDAP Allow Clear Text Password",	"LDAP Anonymous Identity",
				"LDAP Suffix",						"LDAP Attribute Map v11",
				"LDAP Class Map v11",				"LDAP:searchReferralUsage",
				"LDAP:otherReferralUsage",			"transitionGroupDN",
				"ldapAttributeList",				"ldapClassList",
				"ldapConfigVersion",				"Version",
				"ldapDefaultReferralBehavior",		"ldapTransitionBackLink",
				"ldapSSLConfig"	},
	ASN1ObjID	{2 16 840 1 113719 1 27 6 2}
}

------------------------------------------
-- NCP Server Object Class
------------------------------------------
"NCP Server" OBJECT-CLASS ::=
{
	Operation	MODIFY,
	MayContain	{"LDAP Server"}
}


------------------------------------------
-- Specific Attributes for User class
------------------------------------------
"Internet EMail Address" ATTRIBUTE ::=
{
	SyntaxID	SYN_CI_STRING,
	Flags		{DS_PUBLIC_READ, DS_SYNC_IMMEDIATE},
	ASN1ObjID	{0 9 2342 19200300 100 1 3}
}

-- RFC 1274
-- "EmployeeNumber" (defined in May, 1998 for a Beta before NetWare 5 release) has integer flag ..
-- .. , single value, and bad OID.
-- "Employee ID" (defined in NetWare 5 and Support Pack 1) is a single value attribute with bad OID.
-- The following definition has correct syntax, flags, and OID for NetWare 5 NDS v8.
-- This is mapped to "employeeNumber" inside LDAP

"NSCP:employeeNumber" ATTRIBUTE ::=
{
	SyntaxID	SYN_CI_STRING,
	Flags		{DS_SYNC_IMMEDIATE},
	ASN1ObjID	{2 16 840 1 113730 3 1 3}
}

"Organizational Person" OBJECT-CLASS ::=
{
	Operation	MODIFY,
	MayContain	{"Internet EMail Address", "NSCP:employeeNumber" }
}

--------------------------------------------------------------
-- LDAP Referral Include and Exclude List Attributes
-- To Restrict the referrals being returned by the LDAP server
--------------------------------------------------------------
-- LDAPSchemaExtentions DEFINITIONS ::=

"referralExcludeFilter" ATTRIBUTE ::=
{
	SyntaxID	SYN_CI_STRING,
	Flags		{DS_SYNC_IMMEDIATE},
	ASN1ObjID	{2 16 840 1 113719 1 27 4 76}
}

"referralIncludeFilter" ATTRIBUTE ::=
{
	SyntaxID	SYN_CI_STRING,
	Flags		{DS_SYNC_IMMEDIATE},
	ASN1ObjID	{2 16 840 1 113719 1 27 4 77}
}

"LDAP Group" OBJECT-CLASS ::=
{
	Operation MODIFY,
	MayContain { "referralIncludeFilter", "referralExcludeFilter"}
}

END
