-- CoPyRiGhT=Copyright (c) 2013 NetIQ Corporation and its affiliates. All Rights Reserved.
-- Schema Source:		NOV_INET.sch
-- Description:			inetorgperson schema definitions
-- %version:            10 %
-- %date_modified:		Tue Jun  5 14:10:18 2007 %

-- This file implements the schema defined by RFC2798
-- "Definition of the inetOrgPerson LDAP Object Class"
-- by adding all the appropriate attributes to 
-- the NetIQ USER class definition

UserForInetOrgPersonExtentions DEFINITIONS ::=
BEGIN

-- Netscape extension to the standard LDAP schema

"audio" ATTRIBUTE ::=
{
	SyntaxID    SYN_OCTET_STRING,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {0 9 2342 19200300 100 1 55}
}

-- Duplicated from the ldapupdt.sch file for completeness here
"businessCategory" ATTRIBUTE ::=
{
	SyntaxID    SYN_CI_STRING,
	Flags       {DS_SIZED_ATTR, DS_SYNC_IMMEDIATE},
	LowerBound  1,
	UpperBound  128,
	ASN1ObjID   {2 5 4 15}
}
									
"carLicense" ATTRIBUTE ::=
{
	SyntaxID    SYN_CI_STRING,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113730 3 1 1}
}

"departmentNumber" ATTRIBUTE ::=
{
	SyntaxID    SYN_CI_STRING,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113730 3 1 2}
}

"displayName" ATTRIBUTE ::=
{
	SyntaxID    SYN_CI_STRING,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113730 3 1 241}
}

-- Duplicated from the ldap.sch file for completeness here.  NetIQ's LDAP
-- implementation creates a mapping from NSCP:employeeNumber to employeeNumber
"NSCP:employeeNumber" ATTRIBUTE ::=
{
	SyntaxID	SYN_CI_STRING,
	Flags		{DS_SYNC_IMMEDIATE},
	ASN1ObjID	{2 16 840 1 113730 3 1 3}
}

"employeeType" ATTRIBUTE ::=
{
	SyntaxID    SYN_CI_STRING,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113730 3 1 4}
}

"jpegPhoto" ATTRIBUTE ::=
{
	SyntaxID    SYN_OCTET_STRING,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {0 9 2342 19200300 100 1 60}
}

"homePhone" ATTRIBUTE ::=
{
	SyntaxID    SYN_TEL_NUMBER,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {0 9 2342 19200300 100 1 20}
}

"homePostalAddress" ATTRIBUTE ::=
{
	SyntaxID    SYN_PO_ADDRESS,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {0 9 2342 19200300 100 1 39}
}

"labeledUri" ATTRIBUTE ::=
{
	SyntaxID    SYN_CI_STRING,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {1 3 6 1 4 1 250 1 57}
}

"manager" ATTRIBUTE ::=
{
	SyntaxID		SYN_DIST_NAME,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {0 9 2342 19200300 100 1 10}
}

"mobile" ATTRIBUTE ::=
{
	SyntaxID    SYN_TEL_NUMBER,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {0 9 2342 19200300 100 1 41}
}

"pager" ATTRIBUTE ::=
{
	SyntaxID    SYN_TEL_NUMBER,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {0 9 2342 19200300 100 1 42}
}

"ldapPhoto" ATTRIBUTE ::=
{
	SyntaxID    SYN_OCTET_STRING,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {0 9 2342 19200300 100 1 7}
}

"preferredLanguage" ATTRIBUTE ::=
{
	SyntaxID    SYN_CI_STRING,
	Flags       {DS_SINGLE_VALUED_ATTR, DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113730 3 1 39}
}

"secretary" ATTRIBUTE ::=
{
	SyntaxID		SYN_DIST_NAME,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {0 9 2342 19200300 100 1 21}
}

"userSMIMECertificate" ATTRIBUTE ::=
{
	SyntaxID    SYN_OCTET_STRING,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113730 3 1 40}
}

"userPKCS12" ATTRIBUTE ::=
{
	SyntaxID    SYN_OCTET_STRING,
	Flags       {DS_SYNC_IMMEDIATE},
	ASN1ObjID   {2 16 840 1 113730 3 1 216}
}

-- Netscape extension to the standard LDAP schema
"User" OBJECT-CLASS ::=
{
	Operation   MODIFY,
	MayContain  {
					"audio",										"businessCategory",
					"carLicense",								"departmentNumber",
					"NSCP:employeeNumber",					"employeeType",
					"displayName",								"Given Name",
					"homePhone",								"homePostalAddress",
					"Initials",									"jpegPhoto",
					"labeledUri",								"Internet EMail Address",
					"manager",									"mobile",
					"o",											"pager",
					"ldapPhoto",								"preferredLanguage",
					"roomNumber",								"secretary",
					"uniqueID",									"userCertificate",
					"userSMIMECertificate",					"x500UniqueIdentifier",
					"userPKCS12"}
}

END
